Endpoints
=========

Analytics Endpoint
------------------

.. autoclass:: pydhis2.endpoints.analytics.AnalyticsEndpoint
   :members:
   :undoc-members:
   :show-inheritance:

DataValueSets Endpoint
----------------------

.. autoclass:: pydhis2.endpoints.datavaluesets.DataValueSetsEndpoint
   :members:
   :undoc-members:
   :show-inheritance:

Tracker Endpoint
----------------

.. autoclass:: pydhis2.endpoints.tracker.TrackerEndpoint
   :members:
   :undoc-members:
   :show-inheritance:

Metadata Endpoint
-----------------

.. autoclass:: pydhis2.endpoints.metadata.MetadataEndpoint
   :members:
   :undoc-members:
   :show-inheritance:

